//
// This code is part of https://developer.mescius.com/document-solutions/dot-net-imaging-api/demos.
// Copyright (c) MESCIUS inc. All rights reserved.
//
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Drawing;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Imaging;
using GCTEXT = GrapeCity.Documents.Text;
using GCDRAW = GrapeCity.Documents.Drawing;

namespace DsImagingWeb.Demos
{
    // This sample demonstrates how to use LuminanceToAlphaEffect,
    // OpacityEffect and SepiaEffect on an image.
    // See also MatrixEffects1.
    public class MatrixEffects2
    {
        public GcBitmap GenerateImage(Size pixelSize, float dpi, bool opaque, string[] sampleParams = null)
        {
            opaque = false;
            var bmp = new GcBitmap(pixelSize.Width, pixelSize.Height, opaque, dpi, dpi);
            using (var origBmp = new GcBitmap())
            {
                // Load a sample photo:
                var imagePath = Path.Combine("Resources", "Images", "lavender.jpg");
                using (var stm = new FileStream(imagePath, FileMode.Open, FileAccess.Read, FileShare.Read, 4096, FileOptions.RandomAccess))
                    origBmp.Load(stm);

                origBmp.SetAlphaTo255();
                origBmp.Opaque = false;

                // Resize the original photo so we can place 4 samples of it
                // on the resulting bitmap:
                int w = pixelSize.Width / 2;
                int h = pixelSize.Height / 2;
                using (var sizedBmp = origBmp.Resize(w, h, InterpolationMode.Cubic))
                {
                    sizedBmp.Opaque = opaque;
                    // Copy the resized original into 4 quadrants of the resulting bitmap:
                    bmp.BitBlt(sizedBmp, 0, 0);
                    bmp.BitBlt(sizedBmp, w, 0);
                    bmp.BitBlt(sizedBmp, 0, h);
                    bmp.BitBlt(sizedBmp, w, h);
                }

                // Moving the 3 lines with the "ApplyEffect" comment from below to here
                // will apply the effects only to the photos but not to the texts.

                // Add borders between the quadrants, and captions for each:
                var lineh = 2;
                using (var g = bmp.CreateGraphics(null))
                {
                    var foreColor = Color.Yellow;
                    var backColor = Color.Blue;
                    var font = GCTEXT.Font.FromFile(Path.Combine("Resources", "Fonts", "cour.ttf"));
                    g.DrawLine(w, 0, w, h * 2, new GCDRAW.Pen(foreColor, lineh * 2));
                    g.DrawLine(0, h, w * 2, h, new GCDRAW.Pen(foreColor, lineh * 2));
                    var tf = new TextFormat() { Font = font, FontSize = 18, ForeColor = foreColor, BackColor = backColor, FontBold = true };
                    g.DrawString(" Original image ", tf, new PointF(0, 0));
                    g.DrawString(" LuminanceToAlphaEffect.Get() ", tf, new PointF(w + lineh, 0));
                    g.DrawString(" OpacityEffect.Get(0.5f) ", tf, new PointF(0, h + lineh));
                    g.DrawString(" SepiaEffect.Get() ", tf, new PointF(w + lineh, h + lineh));
                }
                // ApplyEffect (move this code up to before drawing texts
                // to limit it to photos only and not affect the captions).
                //
                // Keep the pixels in top left quadrant intact,
                // apply effects to the other 3 quadrants:
                bmp.ApplyEffect(LuminanceToAlphaEffect.Get(), new Rectangle(w + lineh, 0, w - lineh, h - lineh));
                bmp.ApplyEffect(OpacityEffect.Get(0.5f), new Rectangle(0, h + lineh, w - lineh, h - lineh));
                bmp.ApplyEffect(SepiaEffect.Get(), new Rectangle(w + lineh, h + lineh, w - lineh, h - lineh));
            }
            return bmp;
        }
    }
}
